pub struct ResumeSessionKernelReplay {Show 39 fields
pub turn_count: usize,
pub turns_with_events: usize,
pub turns_coherent: usize,
pub all_coherent: bool,
pub latest_turn_id: Option<String>,
pub latest_step_idx: Option<u32>,
pub latest_max_steps: Option<u32>,
pub active_tool_count: Option<u32>,
pub model_message_count: Option<u32>,
pub tool_call_planned_count: Option<u32>,
pub message_coverage_ok: Option<bool>,
pub message_coverage_summary: Option<String>,
pub message_timeline_ok: Option<bool>,
pub message_timeline_summary: Option<String>,
pub kernel_model_request_count: Option<u32>,
pub kernel_estimated_min_session_messages: Option<u32>,
pub message_role_index_ok: Option<bool>,
pub message_role_index_summary: Option<String>,
pub message_memory_plane_ok: Option<bool>,
pub message_memory_plane_summary: Option<String>,
pub message_compaction_depth_ok: Option<bool>,
pub message_compaction_summary: Option<String>,
pub message_compaction_artifact_ok: Option<bool>,
pub message_compaction_artifact_summary: Option<String>,
pub message_continuation_anchor_ok: Option<bool>,
pub message_continuation_anchor_summary: Option<String>,
pub message_notify_lsp_anchor_ok: Option<bool>,
pub message_notify_lsp_anchor_summary: Option<String>,
pub message_request_approval_anchor_ok: Option<bool>,
pub message_request_approval_anchor_summary: Option<String>,
pub message_memory_plane_replay_anchor_ok: Option<bool>,
pub message_memory_plane_replay_anchor_summary: Option<String>,
pub message_compaction_replay_anchor_ok: Option<bool>,
pub message_compaction_replay_anchor_summary: Option<String>,
pub replay_effect_counts: Option<ReplayEffectCounts>,
pub replay_anchor_effect_count: Option<u32>,
pub kernel_transcript_preview_row_count: Option<u32>,
pub message_transcript_preview_ok: Option<bool>,
pub message_transcript_preview_body_ok: Option<bool>,
}Fields
turn_count: usizeturns_with_events: usizeturns_coherent: usizeall_coherent: boollatest_turn_id: Option<String>latest_step_idx: Option<u32>latest_max_steps: Option<u32>active_tool_count: Option<u32>model_message_count: Option<u32>tool_call_planned_count: Option<u32>message_coverage_ok: Option<bool>message_coverage_summary: Option<String>message_timeline_ok: Option<bool>message_timeline_summary: Option<String>kernel_model_request_count: Option<u32>kernel_estimated_min_session_messages: Option<u32>message_role_index_ok: Option<bool>message_role_index_summary: Option<String>message_memory_plane_ok: Option<bool>message_memory_plane_summary: Option<String>message_compaction_depth_ok: Option<bool>message_compaction_summary: Option<String>message_compaction_artifact_ok: Option<bool>message_compaction_artifact_summary: Option<String>message_continuation_anchor_ok: Option<bool>message_continuation_anchor_summary: Option<String>message_notify_lsp_anchor_ok: Option<bool>message_notify_lsp_anchor_summary: Option<String>message_request_approval_anchor_ok: Option<bool>message_request_approval_anchor_summary: Option<String>message_memory_plane_replay_anchor_ok: Option<bool>message_memory_plane_replay_anchor_summary: Option<String>message_compaction_replay_anchor_ok: Option<bool>message_compaction_replay_anchor_summary: Option<String>replay_effect_counts: Option<ReplayEffectCounts>replay_anchor_effect_count: Option<u32>Anchor-class replay effect total (inject_steer + run_compaction + notify_lsp).
kernel_transcript_preview_row_count: Option<u32>message_transcript_preview_ok: Option<bool>message_transcript_preview_body_ok: Option<bool>Trait Implementations
Sourceimpl Clone for ResumeSessionKernelReplay
impl Clone for ResumeSessionKernelReplay
Sourcefn clone(&self) -> ResumeSessionKernelReplay
fn clone(&self) -> ResumeSessionKernelReplay
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResumeSessionKernelReplay
impl Debug for ResumeSessionKernelReplay
Sourceimpl<'de> Deserialize<'de> for ResumeSessionKernelReplay
impl<'de> Deserialize<'de> for ResumeSessionKernelReplay
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResumeSessionKernelReplay
impl JsonSchema for ResumeSessionKernelReplay
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ResumeSessionKernelReplay
impl RefUnwindSafe for ResumeSessionKernelReplay
impl Send for ResumeSessionKernelReplay
impl Sync for ResumeSessionKernelReplay
impl Unpin for ResumeSessionKernelReplay
impl UnsafeUnpin for ResumeSessionKernelReplay
impl UnwindSafe for ResumeSessionKernelReplay