pub struct ResumeSessionResponse {
pub thread_id: String,
pub session_id: String,
pub message_count: usize,
pub state: String,
pub kernel_replay: Option<ResumeSessionKernelReplay>,
}Fields
thread_id: Stringsession_id: Stringmessage_count: usizestate: Stringkernel_replay: Option<ResumeSessionKernelReplay>Trait Implementations
Sourceimpl Clone for ResumeSessionResponse
impl Clone for ResumeSessionResponse
Sourcefn clone(&self) -> ResumeSessionResponse
fn clone(&self) -> ResumeSessionResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResumeSessionResponse
impl Debug for ResumeSessionResponse
Sourceimpl<'de> Deserialize<'de> for ResumeSessionResponse
impl<'de> Deserialize<'de> for ResumeSessionResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResumeSessionResponse
impl JsonSchema for ResumeSessionResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ResumeSessionResponse
impl RefUnwindSafe for ResumeSessionResponse
impl Send for ResumeSessionResponse
impl Sync for ResumeSessionResponse
impl Unpin for ResumeSessionResponse
impl UnsafeUnpin for ResumeSessionResponse
impl UnwindSafe for ResumeSessionResponse