pub struct SessionDetailResponse {
pub metadata: SessionMetadata,
pub messages: Vec<Value>,
pub system_prompt: Option<String>,
}Fields
metadata: SessionMetadatamessages: Vec<Value>system_prompt: Option<String>Trait Implementations
Sourceimpl Clone for SessionDetailResponse
impl Clone for SessionDetailResponse
Sourcefn clone(&self) -> SessionDetailResponse
fn clone(&self) -> SessionDetailResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionDetailResponse
impl Debug for SessionDetailResponse
Sourceimpl<'de> Deserialize<'de> for SessionDetailResponse
impl<'de> Deserialize<'de> for SessionDetailResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SessionDetailResponse
impl JsonSchema for SessionDetailResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SessionDetailResponse
impl RefUnwindSafe for SessionDetailResponse
impl Send for SessionDetailResponse
impl Sync for SessionDetailResponse
impl Unpin for SessionDetailResponse
impl UnsafeUnpin for SessionDetailResponse
impl UnwindSafe for SessionDetailResponse