pub struct SessionsListResponse {
pub sessions: Vec<SessionMetadata>,
}Fields
sessions: Vec<SessionMetadata>Trait Implementations
Sourceimpl Clone for SessionsListResponse
impl Clone for SessionsListResponse
Sourcefn clone(&self) -> SessionsListResponse
fn clone(&self) -> SessionsListResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionsListResponse
impl Debug for SessionsListResponse
Sourceimpl<'de> Deserialize<'de> for SessionsListResponse
impl<'de> Deserialize<'de> for SessionsListResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SessionsListResponse
impl JsonSchema for SessionsListResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SessionsListResponse
impl RefUnwindSafe for SessionsListResponse
impl Send for SessionsListResponse
impl Sync for SessionsListResponse
impl Unpin for SessionsListResponse
impl UnsafeUnpin for SessionsListResponse
impl UnwindSafe for SessionsListResponse