pub struct StreamTurnRequest {
pub prompt: String,
pub model: Option<String>,
pub mode: Option<String>,
pub workspace: Option<String>,
pub allow_shell: Option<bool>,
pub trust_mode: Option<bool>,
pub auto_approve: Option<bool>,
pub route_intent: Option<String>,
pub task_type: Option<String>,
pub temperature: Option<f32>,
pub top_p: Option<f32>,
pub max_tokens: Option<u32>,
}Fields
prompt: Stringmodel: Option<String>mode: Option<String>workspace: Option<String>allow_shell: Option<bool>trust_mode: Option<bool>auto_approve: Option<bool>route_intent: Option<String>task_type: Option<String>temperature: Option<f32>top_p: Option<f32>max_tokens: Option<u32>Trait Implementations
Sourceimpl Clone for StreamTurnRequest
impl Clone for StreamTurnRequest
Sourcefn clone(&self) -> StreamTurnRequest
fn clone(&self) -> StreamTurnRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StreamTurnRequest
impl Debug for StreamTurnRequest
Sourceimpl<'de> Deserialize<'de> for StreamTurnRequest
impl<'de> Deserialize<'de> for StreamTurnRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StreamTurnRequest
impl JsonSchema for StreamTurnRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StreamTurnRequest
impl RefUnwindSafe for StreamTurnRequest
impl Send for StreamTurnRequest
impl Sync for StreamTurnRequest
impl Unpin for StreamTurnRequest
impl UnsafeUnpin for StreamTurnRequest
impl UnwindSafe for StreamTurnRequest