pub struct ThreadSummary {
pub id: String,
pub title: String,
pub preview: String,
pub model: String,
pub mode: String,
pub archived: bool,
pub updated_at: String,
pub latest_turn_id: Option<String>,
pub latest_turn_status: Option<String>,
}Fields
id: Stringtitle: Stringpreview: Stringmodel: Stringmode: Stringarchived: boolupdated_at: Stringlatest_turn_id: Option<String>latest_turn_status: Option<String>Trait Implementations
Sourceimpl Clone for ThreadSummary
impl Clone for ThreadSummary
Sourcefn clone(&self) -> ThreadSummary
fn clone(&self) -> ThreadSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ThreadSummary
impl Debug for ThreadSummary
Sourceimpl<'de> Deserialize<'de> for ThreadSummary
impl<'de> Deserialize<'de> for ThreadSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ThreadSummary
impl JsonSchema for ThreadSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadSummary
impl RefUnwindSafe for ThreadSummary
impl Send for ThreadSummary
impl Sync for ThreadSummary
impl Unpin for ThreadSummary
impl UnsafeUnpin for ThreadSummary
impl UnwindSafe for ThreadSummary