pub struct TaskCounts {
pub queued: usize,
pub running: usize,
pub completed: usize,
pub failed: usize,
pub canceled: usize,
}Expand description
Count totals by status for task dashboards.
Fields
queued: usizerunning: usizecompleted: usizefailed: usizecanceled: usizeTrait Implementations
Sourceimpl Clone for TaskCounts
impl Clone for TaskCounts
Sourcefn clone(&self) -> TaskCounts
fn clone(&self) -> TaskCounts
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TaskCounts
Sourceimpl Debug for TaskCounts
impl Debug for TaskCounts
Sourceimpl Default for TaskCounts
impl Default for TaskCounts
Sourcefn default() -> TaskCounts
fn default() -> TaskCounts
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TaskCounts
impl<'de> Deserialize<'de> for TaskCounts
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TaskCounts
impl JsonSchema for TaskCounts
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TaskCounts
impl RefUnwindSafe for TaskCounts
impl Send for TaskCounts
impl Sync for TaskCounts
impl Unpin for TaskCounts
impl UnsafeUnpin for TaskCounts
impl UnwindSafe for TaskCounts