pub struct TaskRecord {Show 27 fields
pub schema_version: u32,
pub id: String,
pub prompt: String,
pub model: String,
pub workspace: PathBuf,
pub mode: String,
pub allow_shell: bool,
pub trust_mode: bool,
pub auto_approve: bool,
pub status: TaskStatus,
pub created_at: DateTime<Utc>,
pub started_at: Option<DateTime<Utc>>,
pub ended_at: Option<DateTime<Utc>>,
pub duration_ms: Option<u64>,
pub result_summary: Option<String>,
pub result_detail_path: Option<PathBuf>,
pub error: Option<String>,
pub thread_id: Option<String>,
pub turn_id: Option<String>,
pub runtime_event_count: usize,
pub checklist: TaskChecklistState,
pub gates: Vec<TaskGateRecord>,
pub attempts: Vec<TaskAttemptRecord>,
pub artifacts: Vec<TaskArtifactRef>,
pub github_events: Vec<TaskGithubEvent>,
pub tool_calls: Vec<TaskToolCallSummary>,
pub timeline: Vec<TaskTimelineEntry>,
}Expand description
Durable task record.
Fields
schema_version: u32id: Stringprompt: Stringmodel: Stringworkspace: PathBufmode: Stringallow_shell: booltrust_mode: boolauto_approve: boolstatus: TaskStatuscreated_at: DateTime<Utc>started_at: Option<DateTime<Utc>>ended_at: Option<DateTime<Utc>>duration_ms: Option<u64>result_summary: Option<String>result_detail_path: Option<PathBuf>error: Option<String>thread_id: Option<String>turn_id: Option<String>runtime_event_count: usizechecklist: TaskChecklistStategates: Vec<TaskGateRecord>attempts: Vec<TaskAttemptRecord>artifacts: Vec<TaskArtifactRef>github_events: Vec<TaskGithubEvent>tool_calls: Vec<TaskToolCallSummary>timeline: Vec<TaskTimelineEntry>Trait Implementations
Sourceimpl Clone for TaskRecord
impl Clone for TaskRecord
Sourcefn clone(&self) -> TaskRecord
fn clone(&self) -> TaskRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TaskRecord
impl Debug for TaskRecord
Sourceimpl<'de> Deserialize<'de> for TaskRecord
impl<'de> Deserialize<'de> for TaskRecord
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&TaskRecord> for TaskSummary
impl From<&TaskRecord> for TaskSummary
Sourcefn from(value: &TaskRecord) -> Self
fn from(value: &TaskRecord) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for TaskRecord
impl JsonSchema for TaskRecord
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TaskRecord
impl RefUnwindSafe for TaskRecord
impl Send for TaskRecord
impl Sync for TaskRecord
impl Unpin for TaskRecord
impl UnsafeUnpin for TaskRecord
impl UnwindSafe for TaskRecord