pub struct TaskSummary {
pub id: String,
pub status: TaskStatus,
pub prompt_summary: String,
pub model: String,
pub mode: String,
pub created_at: DateTime<Utc>,
pub started_at: Option<DateTime<Utc>>,
pub ended_at: Option<DateTime<Utc>>,
pub duration_ms: Option<u64>,
pub error: Option<String>,
pub thread_id: Option<String>,
pub turn_id: Option<String>,
}Expand description
Lightweight task view.
Fields
id: Stringstatus: TaskStatusprompt_summary: Stringmodel: Stringmode: Stringcreated_at: DateTime<Utc>started_at: Option<DateTime<Utc>>ended_at: Option<DateTime<Utc>>duration_ms: Option<u64>error: Option<String>thread_id: Option<String>turn_id: Option<String>Trait Implementations
Sourceimpl Clone for TaskSummary
impl Clone for TaskSummary
Sourcefn clone(&self) -> TaskSummary
fn clone(&self) -> TaskSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TaskSummary
impl Debug for TaskSummary
Sourceimpl<'de> Deserialize<'de> for TaskSummary
impl<'de> Deserialize<'de> for TaskSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&TaskRecord> for TaskSummary
impl From<&TaskRecord> for TaskSummary
Sourcefn from(value: &TaskRecord) -> Self
fn from(value: &TaskRecord) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for TaskSummary
impl JsonSchema for TaskSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TaskSummary
impl RefUnwindSafe for TaskSummary
impl Send for TaskSummary
impl Sync for TaskSummary
impl Unpin for TaskSummary
impl UnsafeUnpin for TaskSummary
impl UnwindSafe for TaskSummary