pub struct TasksResponse {
pub tasks: Vec<TaskSummary>,
pub counts: TaskCounts,
}Fields
tasks: Vec<TaskSummary>counts: TaskCountsTrait Implementations
Sourceimpl Clone for TasksResponse
impl Clone for TasksResponse
Sourcefn clone(&self) -> TasksResponse
fn clone(&self) -> TasksResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TasksResponse
impl Debug for TasksResponse
Sourceimpl<'de> Deserialize<'de> for TasksResponse
impl<'de> Deserialize<'de> for TasksResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TasksResponse
impl JsonSchema for TasksResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TasksResponse
impl RefUnwindSafe for TasksResponse
impl Send for TasksResponse
impl Sync for TasksResponse
impl Unpin for TasksResponse
impl UnsafeUnpin for TasksResponse
impl UnwindSafe for TasksResponse